@@ -4,8 +4,8 @@ import sys,click
 @click.option('-x', '--xmindpath', 'xmindpath', required=True, help='xmind file path')
 @click.option('-e', '--excelpath', 'excelpath', required=True, help='excel file path')
 @click.option('-i', '--ignorelayer', 'ignorelayer', is_flag=True, default='0')
-def test(xmindPath, excelPath, ignorelayer):
-    print(xmindPath + 'haha' + excelPath + 'haha' + ignorelayer)
+def test(xmindpath, excelpath, ignorelayer):
+    print(xmindpath + 'haha' + excelpath + 'haha' + ignorelayer)
     # if ignorelayer == '0':
     #     ConvertXmindToExcel().convert(xmindPath, excelPath)
     # else:
